==> flyyfluttersdk-1.0.0%2B1.tar.gz: lib/views/FlyyTransactionOrderCardDialog.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flyyfluttersdk/helpers/FlyyUtility.dart';
import 'package:flyyfluttersdk/model/FlyyGiftCardData.dart';
import 'package:flyyfluttersdk/model/FlyyGiftCardTransactionOrderData.dart';

class FlyyTransactionOrderCardDialog extends StatelessWidget {
  FlyyGiftCardTransactionOrderData flyyGiftCardData;
  final receiversName = TextEditingController(),
      receiversEmail = TextEditingController();

  FlyyTransactionOrderCardDialog({Key key, @required this.flyyGiftCardData})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Dialog(
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(5),
      ),
      backgroundColor: Colors.white,
      insetPadding: EdgeInsets.all(40),
      child: dialogContent(context),
    );
  }

  //TODO check response
  dialogContent(BuildContext context) {
    return SingleChildScrollView(
      child: Container(
        padding: const EdgeInsets.all(10),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.center,
          children: <Widget>[
            ///gift card name title
            Padding(
              padding: const EdgeInsets.only(bottom: 10, top: 10),
              child: Text(
                flyyGiftCardData.prName,
                style: TextStyle(
                    fontSize: 16, color: FlyyUtility.parseColor('#4a4a4a')),
              ),
            ),

            ///gift card image
            flyyGiftCardData.prImage != null &&
                    flyyGiftCardData.prImage.isNotEmpty
                ? Padding(
                  padding: const EdgeInsets.only(left: 10, right: 10, bottom: 10, top: 10),
                  child: Image.network(
                      flyyGiftCardData.prImage,
                      height: 150,
                      fit: BoxFit.fitHeight,
                    ),
                )
                : SizedBox.shrink(),

            Container(
              margin: const EdgeInsets.only(
                  top: 10, left: 20, right: 20, bottom: 10),
              child: Divider(
                height: 1,
                color: FlyyUtility.parseColor('#9A9A9A'),
              ),
            ),

            Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: <Widget>[
                ///date
                Padding(
                  padding: const EdgeInsets.all(10),
                  child: Row(
//                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: <Widget>[
                      Text(
                        'Date: ',
                        style: TextStyle(
                            fontSize: 13,
                            color: FlyyUtility.parseColor('#9A9A9A')),
                      ),
                      Text(
                        FlyyUtility.getFormattedDateDDMMMYYY(
                            flyyGiftCardData.createdAt),
                        style: TextStyle(
                            fontSize: 13,
                            color: FlyyUtility.parseColor('#323232')),
                      )
                    ],
                  ),
                ),

                ///ref number
                Padding(
                  padding:
                      const EdgeInsets.only(bottom: 10, left: 10, right: 10),
                  child: Row(
//                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: <Widget>[
                      Text(
                        'Ref Number: ',
                        style: TextStyle(
                            fontSize: 13,
                            color: FlyyUtility.parseColor('#9A9A9A')),
                      ),
                      Text(
                        flyyGiftCardData.refNumber != null
                            ? flyyGiftCardData.refNumber
                            : "",
                        style: TextStyle(
                            fontSize: 13,
                            color: FlyyUtility.parseColor('#323232')),
                      )
                    ],
                  ),
                ),

                ///Name
                Padding(
                  padding:
                      const EdgeInsets.only(bottom: 10, left: 10, right: 10),
                  child: Row(
//                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: <Widget>[
                      Text(
                        'Name: ',
                        style: TextStyle(
                            fontSize: 13,
                            color: FlyyUtility.parseColor('#9A9A9A')),
                      ),
                      Text(
                        flyyGiftCardData.name,
                        style: TextStyle(
                            fontSize: 13,
                            color: FlyyUtility.parseColor('#323232')),
                      )
                    ],
                  ),
                ),

                ///Email
                Padding(
                  padding:
                      const EdgeInsets.only(bottom: 10, left: 10, right: 10),
                  child: Row(
//                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: <Widget>[
                      Text(
                        'Email: ',
                        style: TextStyle(
                            fontSize: 13,
                            color: FlyyUtility.parseColor('#9A9A9A')),
                      ),
                      Flexible(
                        child: Text(
                          flyyGiftCardData.email,
                          overflow: TextOverflow.ellipsis,
                          style: TextStyle(
                              fontSize: 13,
                              color: FlyyUtility.parseColor('#323232')),
                        ),
                      )
                    ],
                  ),
                ),

                ///value
                Padding(
                  padding:
                      const EdgeInsets.only(bottom: 10, left: 10, right: 10),
                  child: Row(
//                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: <Widget>[
                      Text(
                        'Gift Card Value: ',
                        style: TextStyle(
                            fontSize: 13,
                            color: FlyyUtility.parseColor('#9A9A9A')),
                      ),
                      Text(
                        '₹' + flyyGiftCardData.amount.toString(),
                        style: TextStyle(
                            fontSize: 13,
                            color: FlyyUtility.parseColor('#323232')),
                      )
                    ],
                  ),
                ),

                ///balance used
                Padding(
                  padding:
                      const EdgeInsets.only(bottom: 20, left: 10, right: 10),
                  child: Row(
//                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: <Widget>[
                      Text(
                        'Balance Used: ',
                        style: TextStyle(
                            fontSize: 13,
                            color: FlyyUtility.parseColor('#9A9A9A')),
                      ),
                      Row(
                        children: <Widget>[
                          flyyGiftCardData.currencyIcon != null &&
                                  flyyGiftCardData.currencyIcon.isNotEmpty
                              ? Image.network(
                                  flyyGiftCardData.currencyIcon,
                                  height: 15,
                                  width: 15,
                                )
                              : SizedBox.shrink(),
                          Padding(
                            padding: const EdgeInsets.only(left: 5),
                            child: Text(
                              FlyyUtility.setRewardText(flyyGiftCardData.tokens,
                                  flyyGiftCardData.currencyLabel),
                              style: TextStyle(
                                  fontSize: 13,
                                  color: FlyyUtility.parseColor('#323232')),
                            ),
                          )
                        ],
                      )
                    ],
                  ),
                ),
              ],
            )
          ],
        ),
      ),
    );
  }
}

==> flyyfluttersdk-1.0.4%2B1.tar.gz: lib/views/FlyyTransactionOrderCardDialog.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flyyfluttersdk/helpers/FlyyUtility.dart';
import 'package:flyyfluttersdk/model/FlyyGiftCardData.dart';
import 'package:flyyfluttersdk/model/FlyyGiftCardTransactionOrderData.dart';

class FlyyTransactionOrderCardDialog extends StatelessWidget {
  FlyyUtility flyyUtility = new FlyyUtility();
  FlyyGiftCardTransactionOrderData flyyGiftCardData;
  final receiversName = TextEditingController(),
      receiversEmail = TextEditingController();

  FlyyTransactionOrderCardDialog({Key key, @required this.flyyGiftCardData})
      : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Dialog(
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(5),
      ),
      backgroundColor: Colors.white,
      insetPadding: EdgeInsets.all(40),
      child: dialogContent(context),
    );
  }

  //TODO check response
  dialogContent(BuildContext context) {
    return SingleChildScrollView(
      child: Container(
        padding: const EdgeInsets.all(10),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.center,
          children: <Widget>[
            ///gift card name title
            Padding(
              padding: const EdgeInsets.only(bottom: 10, top: 10),
              child: Text(
                flyyGiftCardData.prName,
                style: TextStyle(
                    fontSize: 16, color: FlyyUtility.parseColor('#4a4a4a')),
              ),
            ),

            ///gift card image
            flyyGiftCardData.prImage != null &&
                    flyyGiftCardData.prImage.isNotEmpty
                ? Padding(
                  padding: const EdgeInsets.only(left: 10, right: 10, bottom: 10, top: 10),
                  child: Image.network(
                      flyyGiftCardData.prImage,
                      height: 150,
                      fit: BoxFit.fitHeight,
                    ),
                )
                : SizedBox.shrink(),

            Container(
              margin: const EdgeInsets.only(
                  top: 10, left: 20, right: 20, bottom: 10),
              child: Divider(
                height: 1,
                color: FlyyUtility.parseColor('#9A9A9A'),
              ),
            ),

            Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: <Widget>[
                ///date
                Padding(
                  padding: const EdgeInsets.all(10),
                  child: Row(
//                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: <Widget>[
                      Text(
                        'Date: ',
                        style: TextStyle(
                            fontSize: 13,
                            color: FlyyUtility.parseColor('#9A9A9A')),
                      ),
                      Text(
                        FlyyUtility.getFormattedDateDDMMMYYY(
                            flyyGiftCardData.createdAt),
                        style: TextStyle(
                            fontSize: 13,
                            color: FlyyUtility.parseColor('#323232')),
                      )
                    ],
                  ),
                ),

                ///ref number
                Padding(
                  padding:
                      const EdgeInsets.only(bottom: 10, left: 10, right: 10),
                  child: Row(
//                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: <Widget>[
                      Text(
                        'Ref Number: ',
                        style: TextStyle(
                            fontSize: 13,
                            color: FlyyUtility.parseColor('#9A9A9A')),
                      ),
                      Text(
                        flyyGiftCardData.refNumber != null
                            ? flyyGiftCardData.refNumber
                            : "",
                        style: TextStyle(
                            fontSize: 13,
                            color: FlyyUtility.parseColor('#323232')),
                      )
                    ],
                  ),
                ),

                ///Name
                Padding(
                  padding:
                      const EdgeInsets.only(bottom: 10, left: 10, right: 10),
                  child: Row(
//                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: <Widget>[
                      Text(
                        'Name: ',
                        style: TextStyle(
                            fontSize: 13,
                            color: FlyyUtility.parseColor('#9A9A9A')),
                      ),
                      Text(
                        flyyGiftCardData.name,
                        style: TextStyle(
                            fontSize: 13,
                            color: FlyyUtility.parseColor('#323232')),
                      )
                    ],
                  ),
                ),

                ///Email
                Padding(
                  padding:
                      const EdgeInsets.only(bottom: 10, left: 10, right: 10),
                  child: Row(
//                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: <Widget>[
                      Text(
                        'Email: ',
                        style: TextStyle(
                            fontSize: 13,
                            color: FlyyUtility.parseColor('#9A9A9A')),
                      ),
                      Flexible(
                        child: Text(
                          flyyGiftCardData.email,
                          overflow: TextOverflow.ellipsis,
                          style: TextStyle(
                              fontSize: 13,
                              color: FlyyUtility.parseColor('#323232')),
                        ),
                      )
                    ],
                  ),
                ),

                ///value
                Padding(
                  padding:
                      const EdgeInsets.only(bottom: 10, left: 10, right: 10),
                  child: Row(
//                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: <Widget>[
                      Text(
                        'Gift Card Value: ',
                        style: TextStyle(
                            fontSize: 13,
                            color: FlyyUtility.parseColor('#9A9A9A')),
                      ),
                      Text(
                        '₹' + flyyGiftCardData.amount.toString(),
                        style: TextStyle(
                            fontSize: 13,
                            color: FlyyUtility.parseColor('#323232')),
                      )
                    ],
                  ),
                ),

                ///balance used
                Padding(
                  padding:
                      const EdgeInsets.only(bottom: 20, left: 10, right: 10),
                  child: Row(
//                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: <Widget>[
                      Text(
                        'Balance Used: ',
                        style: TextStyle(
                            fontSize: 13,
                            color: FlyyUtility.parseColor('#9A9A9A')),
                      ),
                      Row(
                        children: <Widget>[
                          flyyGiftCardData.currencyIcon != null &&
                                  flyyGiftCardData.currencyIcon.isNotEmpty
                              ? Image.network(
                                  flyyGiftCardData.currencyIcon,
                                  height: 15,
                                  width: 15,
                                )
                              : SizedBox.shrink(),
                          Padding(
                            padding: const EdgeInsets.only(left: 5),
                            child: Text(
                              flyyUtility.setRewardText(flyyGiftCardData.tokens,
                                  flyyGiftCardData.currencyLabel),
                              style: TextStyle(
                                  fontSize: 13,
                                  color: FlyyUtility.parseColor('#323232')),
                            ),
                          )
                        ],
                      )
                    ],
                  ),
                ),
              ],
            )
          ],
        ),
      ),
    );
  }
}
